/*--------------------------------------------------------------------
 System functions.

 This scripts handles various system functions, like toggling of some
 configuration options (crossfading for example), and temporary output
 in the song ticker (volume, seek, clicks on the player buttons).
--------------------------------------------------------------------*/

#include "../../../lib/std.mi"
#include "../../../lib/config.mi"
#include "../../../lib/pldir.mi"

Function setTempText(String txt);
Function emptyTempText();

Global Text Songticker;
Global Slider Volbar, Seeker, SeekGhost;
Global Timer Songtickertimer;
Global Int Seeking;

Class GuiObject HintObject;

Global HintObject Play, Stop, Previous, Next, Pause, Open, Ml, Pl, Minimize, Shade, Close, Video, AVS, EQ, hpG, hpD;
Global Togglebutton ToggleRepeat, ToggleShuffle, ToggleXFade;
Global button Notif, Theme;

System.onScriptUnloading() {
  delete Songtickertimer;
}

System.onScriptLoaded() {

  // Timers won't start until .start(); is called
  Songtickertimer = new Timer;
  Songtickertimer.setDelay(1000);

  Layout mainnormal = getContainer("main").getLayout("Normal");

  // Get buttons
  ToggleXFade = mainnormal.getObject("Crossfade");
  ToggleShuffle = mainnormal.getObject("Shuffle");
  ToggleRepeat = mainnormal.getObject("Repeat");
  Notif = mainnormal.findObject("pref_notif");
  Theme = mainnormal.findObject("pref_themes");

  // Get songticker, Volbar & Seeker
  Songticker = mainnormal.getObject("Songticker");
  Volbar = mainnormal.getObject("Volume");
  Seeker = mainnormal.getObject("Seeker");
  SeekGhost = mainnormal.getObject("SeekerGhost");

  // Get Various buttons
  Play = mainnormal.getObject("Play");
  Pause = mainnormal.getObject("Pause");
  Stop = mainnormal.getObject("Stop");
  Next = mainnormal.getObject("Next");
  Previous = mainnormal.getObject("Previous");
  Open = mainnormal.getObject("Eject");
  Minimize = mainnormal.getObject("Minimize");
  Shade = mainnormal.getObject("winshade");
  Close = mainnormal.getObject("close");

  Ml = mainnormal.getObject("Ml");
  Pl = mainnormal.getObject("Pl");
  Video = mainnormal.getObject("Video");
  AVS = mainnormal.getObject("AVS");
  EQ = mainnormal.getObject("eq");
  hpG = System.getContainer("egaliseur").getLayout("normal").getObject("hpgauche");
  hpD = System.getContainer("egaliseur").getLayout("normal").getObject("hpdroit");

  if (SeekGhost != NULL)
    SeekGhost.setAlpha(1);
}

Songticker.onLeftButtonDblClk(int x, int y) {
  PlDir.showCurrentlyPlayingEntry();
}

Songtickertimer.onTimer() {
  Songticker.setText("");
  stop();
}

Volbar.onSetPosition(int p) {
  Float f;
  f = p;
  f = f / 255 * 100;
  setTempText("Volume : " + System.integerToString(f) + "%");
}

Volbar.onSetFinalPosition(int p) {
  Songticker.setText("");
}

Seeker.onSetPosition(int p) {
  if (!SeekGhost && seeking) {
    Float f;
    f = p;
    f = f / 255 * 100;
    Float len = getPlayItemLength();
    if (len != 0) {
      int np = len * f / 100;
      setTempText(integerToTime(np) + " / " + integerToTime(len) + " (" + integerToString(f) + "%)");
    }
  }
}

Seeker.onLeftButtonDown(int x, int y) {
  seeking = 1;
}

Seeker.onLeftButtonUp(int x, int y) {
  seeking = 0;
  setTempText("");
}

SeekGhost.onSetPosition(int p) {
  if (getalpha() == 1) return;
  Float f;
  f = p;
  f = f / 255 * 100;
  Float len = getPlayItemLength();
  if (len != 0) {
    int np = len * f / 100;
    setTempText(integerToTime(np) + " / " + integerToTime(len) + " (" + integerToString(f) + "%)");
  }
}

SeekGhost.onLeftButtonDown(int x, int y) {
  SeekGhost.setAlpha(128);
}

SeekGhost.onLeftButtonUp(int x, int y) {
  SeekGhost.setAlpha(1);
}

Seeker.onSetFinalPosition(int p) {
  Songticker.setText("");
}

SeekGhost.onsetfinalposition(int p) {
  Songticker.setText("");
  SeekGhost.setAlpha(1);
}

ToggleRepeat.onToggle(boolean on) {
	int v = getCurCfgVal();
	if (v == 0) setTempText("Repeat : OFF");
          else if (v > 0) setTempText("Repeat : ALL");
          else if (v < 0) setTempText("Repeat : TRACK");
}

ToggleShuffle.onToggle(boolean on) {
	if (on) setTempText("Playlist Shuffling: ON");
          else setTempText("Playlist Shuffling: OFF");
}

ToggleXFade.onToggle(boolean on) {
	if (on) setTempText("Cross Fading : ON");
          else setTempText("Cross Fading : OFF");
}

HintObject.onLeftButtonDown(int x, int y) {
  if (HintObject == Play) setTempText("Play");
  else if (HintObject == Stop) setTempText("Stop");
  else if (HintObject == Pause) setTempText("Pause");
  else if (HintObject == Next) setTempText("Next");
  else if (HintObject == Previous) setTempText("Previous");
  else if (HintObject == Open) setTempText("Open File");
  else if (HintObject == ML) setTempText("Media Library");
  else if (HintObject == Pl) setTempText("Playlist");
  else if (HintObject == Minimize) setTempText("Minimize");
  else if (HintObject == Shade) setTempText("Window Shade");
  else if (HintObject == close) setTempText("Close Winamp ??");
  else if (HintObject == Video) setTempText("Video and TV");
  else if (HintObject == AVS) setTempText("Vizualizer");
  else if (HintObject == EQ) setTempText("Equalizer");
  else if (HintObject == hpG) setTempText("Left Speaker");
  else if (HintObject == hpD) setTempText("Right Speaker");
}

Notif.onLeftButtonDown(int x, int y) {
   setTempText("Notifier Prefs");
}  

Theme.onLeftButtonDown(int x, int y) {
   setTempText("Color Themes");
}  

HintObject.onLeftButtonUp(int x, int y) {
  emptyTempText();
}

setTempText(String txt) {
  Songtickertimer.stop();
  Songticker.setText(txt);
  Songtickertimer.start();
}

emptyTempText() {
  Songticker.setText("");
  Songtickertimer.stop();
}

Songticker.onNotify(String s1, String s2, int i1, int i2) {
  setTempText(s1);
}
